//    This file is part of Motion Watch.

//    Motion Watch is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.

//    Motion Watch is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.

#include "logger.h"

void recLog(const string &line, shared_t *share)
{
    share->recLogFile << genTimeStr("[%Y-%m-%d-%H-%M-%S] ") << line << "<br>" << endl;
}

void detLog(const string &line, shared_t *share)
{
    share->detLogFile << genTimeStr("[%Y-%m-%d-%H-%M-%S] ") << line << "<br>" << endl;
}

void enforceMaxLogSize(const string &filePath, shared_t *share)
{
    if (exists(filePath))
    {
        if (file_size(filePath) >= share->maxLogSize)
        {
            remove(filePath);
        }
    }
}

void initLogFile(const string &filePath, ofstream &fileObj)
{
    if (!fileObj.is_open())
    {
        if (!exists(filePath))
        {
            system(string("touch " + filePath).c_str());
        }

        fileObj.open(filePath.c_str(), ofstream::app | ofstream::out);
    }
}

void initLogFrontPage(const string &filePath, const string &logLinesFile)
{
    string htmlText = "<!DOCTYPE html>\n";

    htmlText += "<html>\n";
    htmlText += "<script>\n";
    htmlText += "function includeHTML() {\n";
    htmlText += "  var z, i, elmnt, file, xhttp;\n";
    htmlText += "  z = document.getElementsByTagName(\"*\");\n";
    htmlText += "  for (i = 0; i < z.length; i++) {\n";
    htmlText += "    elmnt = z[i];\n";
    htmlText += "    file = elmnt.getAttribute(\"include-html\");\n";
    htmlText += "    if (file) {\n";
    htmlText += "      xhttp = new XMLHttpRequest();\n";
    htmlText += "      xhttp.onreadystatechange = function() {\n";
    htmlText += "        if (this.readyState == 4) {\n";
    htmlText += "          if (this.status == 200) {elmnt.innerHTML = this.responseText;}\n";
    htmlText += "          if (this.status == 404) {elmnt.innerHTML = \"Page not found.\";}\n";
    htmlText += "          elmnt.removeAttribute(\"include-html\");\n";
    htmlText += "          includeHTML();\n";
    htmlText += "        }\n";
    htmlText += "      }\n";
    htmlText += "      xhttp.open(\"GET\", file, true);\n";
    htmlText += "      xhttp.send();\n";
    htmlText += "      return;\n";
    htmlText += "    }\n";
    htmlText += "  }\n";
    htmlText += "};\n";
    htmlText += "</script>\n";
    htmlText += "<head>\n";
    htmlText += "<link rel='stylesheet' href='/theme.css'>\n";
    htmlText += "</head>\n";
    htmlText += "<body>\n";
    htmlText += "<p>\n";
    htmlText += "<div include-html='" + logLinesFile + "'></div>\n";
    htmlText += "<script>\n";
    htmlText += "includeHTML();\n";
    htmlText += "</script>\n";
    htmlText += "</p>\n";
    htmlText += "</body>\n";
    htmlText += "</html>\n";

    ofstream outFile(filePath);

    outFile << htmlText;

    outFile.close();
}

void initLogFrontPages(shared_t *share)
{
    auto recLogFilePath = share->outDir + "/recording_log.html";
    auto detLogFilePath = share->outDir + "/detection_log.html";

    initLogFrontPage(recLogFilePath, path(share->recLogPath).filename().string());
    initLogFrontPage(detLogFilePath, path(share->detLogPath).filename().string());
}
